==> my-data-toolkit-0.0.19.tar.gz: my-data-toolkit-0.0.19/dtoolkit/accessor/series/__init__.py <==
from dtoolkit.accessor.series.bin import bin  # noqa: F401
from dtoolkit.accessor.series.change_axis_type import change_axis_type  # noqa: F401
from dtoolkit.accessor.series.cols import cols  # noqa: F401
from dtoolkit.accessor.series.drop_inf import drop_inf  # noqa: F401
from dtoolkit.accessor.series.dropna_index import dropna_index  # noqa: F401
from dtoolkit.accessor.series.equal import equal  # noqa: F401
from dtoolkit.accessor.series.error_report import error_report  # noqa: F401
from dtoolkit.accessor.series.eval import eval  # noqa: F401
from dtoolkit.accessor.series.expand import expand  # noqa: F401
from dtoolkit.accessor.series.filter_in import filter_in  # noqa: F401
from dtoolkit.accessor.series.getattr import getattr  # noqa: F401
from dtoolkit.accessor.series.groupby_index import groupby_index  # noqa: F401
from dtoolkit.accessor.series.jenks_bin import jenks_bin  # noqa: F401
from dtoolkit.accessor.series.jenks_breaks import jenks_breaks  # noqa: F401
from dtoolkit.accessor.series.len import len  # noqa: F401
from dtoolkit.accessor.series.query import query  # noqa: F401
from dtoolkit.accessor.series.set_unique_index import set_unique_index  # noqa: F401
from dtoolkit.accessor.series.swap_index_values import swap_index_values  # noqa: F401
from dtoolkit.accessor.series.textdistance import textdistance  # noqa: F401
from dtoolkit.accessor.series.textdistance_matrix import (  # noqa: F401
    textdistance_matrix,
)
from dtoolkit.accessor.series.to_datetime import to_datetime  # noqa: F401
from dtoolkit.accessor.series.to_set import to_set  # noqa: F401
from dtoolkit.accessor.series.top_n import top_n  # noqa: F401
from dtoolkit.accessor.series.values_to_dict import values_to_dict  # noqa: F401

==> my-data-toolkit-0.0.20rc1.tar.gz: my-data-toolkit-0.0.20rc1/dtoolkit/accessor/series/__init__.py <==
from dtoolkit.accessor.series.bin import bin  # noqa: F401
from dtoolkit.accessor.series.change_axis_type import change_axis_type  # noqa: F401
from dtoolkit.accessor.series.cols import cols  # noqa: F401
from dtoolkit.accessor.series.drop_inf import drop_inf  # noqa: F401
from dtoolkit.accessor.series.dropna_index import dropna_index  # noqa: F401
from dtoolkit.accessor.series.equal import equal  # noqa: F401
from dtoolkit.accessor.series.error_report import error_report  # noqa: F401
from dtoolkit.accessor.series.eval import eval  # noqa: F401
from dtoolkit.accessor.series.expand import expand  # noqa: F401
from dtoolkit.accessor.series.filter_in import filter_in  # noqa: F401
from dtoolkit.accessor.series.getattr import getattr  # noqa: F401
from dtoolkit.accessor.series.groupby_index import groupby_index  # noqa: F401
from dtoolkit.accessor.series.invert_or_not import invert_or_not  # noqa: F401
from dtoolkit.accessor.series.jenks_bin import jenks_bin  # noqa: F401
from dtoolkit.accessor.series.jenks_breaks import jenks_breaks  # noqa: F401
from dtoolkit.accessor.series.len import len  # noqa: F401
from dtoolkit.accessor.series.query import query  # noqa: F401
from dtoolkit.accessor.series.set_unique_index import set_unique_index  # noqa: F401
from dtoolkit.accessor.series.swap_index_values import swap_index_values  # noqa: F401
from dtoolkit.accessor.series.textdistance import textdistance  # noqa: F401
from dtoolkit.accessor.series.textdistance_matrix import (  # noqa: F401
    textdistance_matrix,
)
from dtoolkit.accessor.series.to_datetime import to_datetime  # noqa: F401
from dtoolkit.accessor.series.to_set import to_set  # noqa: F401
from dtoolkit.accessor.series.to_zh import to_zh  # noqa: F401
from dtoolkit.accessor.series.top_n import top_n  # noqa: F401
from dtoolkit.accessor.series.values_to_dict import values_to_dict  # noqa: F401
